Automatic setup
~~~~~~~~~~~~~~~

It's quick and easy to get started using Coiled in your own cloud provider account. This guide will cover the steps for getting started with Coiled using the command-line interface, all from your terminal.

.. toctree::
   :maxdepth: 1

   aws-cli
   gcp-cli
